@@ -1,6 +1,7 @@
 /* encavcodec.c
 
    Copyright (c) 2003-2022 HandBrake Team
+   Copyright 2022 NVIDIA Corporation
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -12,6 +13,7 @@
 #include "handbrake/hbffmpeg.h"
 #include "handbrake/h264_common.h"
 #include "handbrake/h265_common.h"
+#include "handbrake/av1_common.h"
 #include "handbrake/nal_units.h"
 
 #if HB_PROJECT_FEATURE_NVENC
@@ -25,11 +27,11 @@
  * frame number, we use this as an index.
  *
  * The size of the array is chosen so that two frames can't use the same
- * slot during the encoder's max frame delay (set by the standard as 16
- * frames) and so that, up to some minimum frame rate, frames are guaranteed
+ * slot during the encoder's max frame delay and so that,
+ * up to some minimum frame rate, frames are guaranteed
  * to map to * different slots.
  */
-#define FRAME_INFO_SIZE 32
+#define FRAME_INFO_SIZE 1024
 #define FRAME_INFO_MASK (FRAME_INFO_SIZE - 1)
 
 struct hb_work_private_s
@@ -59,6 +61,8 @@ void encavcodecClose( hb_work_object_t * );
 
 static int apply_encoder_preset(int vcodec, AVDictionary ** av_opts,
                                 const char * preset);
+static int apply_encoder_options(hb_job_t *job, AVCodecContext *context,
+                                 AVDictionary **av_opts);
 
 hb_work_object_t hb_encavcodec =
 {
@@ -79,6 +83,21 @@ static const char * const h26x_nvenc_preset_names[] =
     "fastest", "faster", "fast", "medium", "slow", "slower", "slowest", NULL
 };
 
+static const char * const av1_svt_preset_names[] =
+{
+    "12", "11", "10", "9", "8", "7", "6", "5", "4", "3", "2", "1", "0", NULL
+};
+
+static const char * const av1_svt_tune_names[] =
+{
+    "psnr", "fastdecode", NULL
+};
+
+static const char * const av1_svt_profile_names[] =
+{
+    "auto", "main", NULL // "high", "profesional"
+};
+
 static const char * const h264_nvenc_profile_names[] =
 {
     "auto", "baseline", "main", "high", NULL  // "high444p" not supported.
@@ -86,7 +105,12 @@ static const char * const h264_nvenc_profile_names[] =
 
 static const char * const h265_nvenc_profile_names[] =
 {
-    "auto", "main", NULL // "main10", "rext"  We do not currently support 10bit encodes with this encoder.
+    "auto", "main", NULL
+};
+
+static const char * const h265_nvenc_10bit_profile_names[] =
+{
+    "auto", "main10", NULL
 };
 
 static const char * const h26x_mf_preset_name[] =
@@ -104,22 +128,43 @@ static const char * const h265_mf_profile_name[] =
     "auto", "main",  NULL
 };
 
-static const enum AVPixelFormat pix_fmts[] =
+static const enum AVPixelFormat standard_pix_fmts[] =
 {
     AV_PIX_FMT_YUV420P, AV_PIX_FMT_NONE
 };
 
+static const enum AVPixelFormat standard_10bit_pix_fmts[] =
+{
+    AV_PIX_FMT_YUV420P10, AV_PIX_FMT_NONE
+};
+
 static const enum AVPixelFormat h26x_mf_pix_fmts[] =
 {
     AV_PIX_FMT_NV12, AV_PIX_FMT_NONE
 };
 
+static const enum AVPixelFormat nvenc_pix_formats_10bit[] =
+{
+     AV_PIX_FMT_P010, AV_PIX_FMT_NONE
+};
+
+static const enum AVPixelFormat nvenc_pix_formats[] =
+{
+     AV_PIX_FMT_YUV420P, AV_PIX_FMT_NV12, AV_PIX_FMT_NONE
+};
+
+static const enum AVPixelFormat vce_pix_formats_10bit[] =
+{
+     AV_PIX_FMT_P010, AV_PIX_FMT_NONE
+};
+
+
 int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
 {
     int ret = 0;
     char reason[80];
     char * codec_name = NULL;
-    AVCodec * codec = NULL;
+    const AVCodec * codec = NULL;
     AVCodecContext * context;
     AVRational fps;
 
@@ -184,10 +229,12 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         {
             switch (job->vcodec) {
                 case HB_VCODEC_FFMPEG_NVENC_H265:
+                case HB_VCODEC_FFMPEG_NVENC_H265_10BIT:
                     hb_log("encavcodecInit: H.265 (Nvidia NVENC)");
                     codec_name = "hevc_nvenc";
                     break;
                 case HB_VCODEC_FFMPEG_VCE_H265:
+                case HB_VCODEC_FFMPEG_VCE_H265_10BIT:
                     hb_log("encavcodecInit: H.265 (AMD VCE)");
                     codec_name = "hevc_amf";
                     break;
@@ -197,6 +244,11 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
                     break;
             }
         }break;
+        case AV_CODEC_ID_AV1:
+        {
+            hb_log("encavcodecInit: AV1 encoder");
+            codec_name = "libsvtav1";
+        }break;
     }
 
     if (codec_name == NULL)
@@ -218,7 +270,8 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         ret = 1;
         goto done;
     }
-    context = avcodec_alloc_context3( codec );
+
+    context = avcodec_alloc_context3(codec);
 
     // Set things in context that we will allow the user to
     // override with advanced settings.
@@ -277,7 +330,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
     context->framerate     = fps;
     context->gop_size  = ((double)job->orig_vrate.num / job->orig_vrate.den +
                                   0.5) * 10;
-    if ((job->vcodec == HB_VCODEC_FFMPEG_VCE_H264) || (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265))
+    if ((job->vcodec == HB_VCODEC_FFMPEG_VCE_H264) || (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265) || (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT))
     {
         // Set encoder preset
         context->profile = FF_PROFILE_UNKNOWN;
@@ -292,13 +345,6 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         }
     }
 
-    /* place job->encoder_options in an hb_dict_t for convenience */
-    hb_dict_t * lavc_opts = NULL;
-    if (job->encoder_options != NULL && *job->encoder_options)
-    {
-        lavc_opts = hb_encopts_to_dict(job->encoder_options, job->vcodec);
-    }
-
     AVDictionary * av_opts = NULL;
     if (apply_encoder_preset(job->vcodec, &av_opts, job->encoder_preset))
     {
@@ -308,21 +354,13 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         goto done;
     }
 
-    /* iterate through lavc_opts and have avutil parse the options for us */
-    hb_dict_iter_t iter;
-    for (iter  = hb_dict_iter_init(lavc_opts);
-         iter != HB_DICT_ITER_DONE;
-         iter  = hb_dict_iter_next(lavc_opts, iter))
+    if (apply_encoder_options(job, context, &av_opts))
     {
-        const char *key = hb_dict_iter_key(iter);
-        hb_value_t *value = hb_dict_iter_value(iter);
-        char *str = hb_value_get_string_xform(value);
-
-        /* Here's where the strings are passed to avutil for parsing. */
-        av_dict_set( &av_opts, key, str, 0 );
-        free(str);
+        av_free( context );
+        av_dict_free( &av_opts );
+        ret = 1;
+        goto done;
     }
-    hb_dict_free( &lavc_opts );
 
     // Now set the things in context that we don't want to allow
     // the user to override.
@@ -334,14 +372,13 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         // bitrate * fps
         context->bit_rate_tolerance = context->bit_rate * av_q2d(fps) + 1;
 
-        if ( job->vcodec == HB_VCODEC_FFMPEG_NVENC_H264 ||
-                  job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265 ) {
+        if ( job->vcodec == HB_VCODEC_FFMPEG_NVENC_H264 || job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265 || job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265_10BIT) {
             av_dict_set( &av_opts, "rc", "vbr", 0 );
             av_dict_set( &av_opts, "multipass", "fullres", 0 );
             hb_log( "encavcodec: encoding at rc=vbr, multipass=fullres, Bitrate %d", job->vbitrate );
         }
-        
-        if ( job->vcodec == HB_VCODEC_FFMPEG_VCE_H264 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 )
+
+        if ( job->vcodec == HB_VCODEC_FFMPEG_VCE_H264 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT)
         {
             av_dict_set( &av_opts, "rc", "vbr_peak", 0 );
 
@@ -350,7 +387,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
             context->gop_size = (int)(FFMIN(av_q2d(fps) * 2, 120));
 
             //Work around an ffmpeg issue mentioned in issue #3447
-            if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265)
+            if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT)
             {
                av_dict_set( &av_opts, "qmin",  "0", 0 );
                av_dict_set( &av_opts, "qmax", "51", 0 );
@@ -391,9 +428,19 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
                                          fps.num / fps.den;
             hb_log( "encavcodec: encoding at CQ %.2f", job->vquality );
         }
+        //Set constant quality for svt-av1
+        else if (job->vcodec == HB_VCODEC_FFMPEG_SVT_AV1 ||
+                 job->vcodec == HB_VCODEC_FFMPEG_SVT_AV1_10BIT)
+        {
+            char quality[7];
+            snprintf(quality, 7, "%.2f", job->vquality);
+            av_dict_set( &av_opts, "crf", quality, 0 );
+            hb_log( "encavcodec: encoding at CRF %.2f", job->vquality );
+        }
         //Set constant quality for nvenc
         else if ( job->vcodec == HB_VCODEC_FFMPEG_NVENC_H264 ||
-                  job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265 )
+                  job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265 ||
+                  job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265_10BIT)
         {
             char qualityI[7];
             char quality[7];
@@ -449,7 +496,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
             av_dict_set( &av_opts, "qp_b", qualityB, 0 );
             hb_log( "encavcodec: encoding at QP %.2f", job->vquality );
         }
-        else if ( job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 )
+        else if ( job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT)
         {
             char  *vce_h265_max_au_size_char,
                    vce_h265_q_char[4];
@@ -819,7 +866,19 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
     }
     context->width     = job->width;
     context->height    = job->height;
-    context->pix_fmt   = job->output_pix_fmt;
+#if HB_PROJECT_FEATURE_NVENC
+    if (hb_nvdec_is_enabled(pv->job))
+    {
+        context->hw_device_ctx = pv->job->nv_hw_ctx.hw_device_ctx;
+        hb_nvdec_hwframes_ctx_init(context, job);
+    }
+    else
+    {
+        context->pix_fmt = job->output_pix_fmt;
+    }
+#else
+    context->pix_fmt = job->output_pix_fmt;
+#endif
 
     context->sample_aspect_ratio.num = job->par.num;
     context->sample_aspect_ratio.den = job->par.den;
@@ -841,6 +900,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
     context->color_primaries = hb_output_color_prim(job);
     context->color_trc       = hb_output_color_transfer(job);
     context->colorspace      = hb_output_color_matrix(job);
+    context->color_range     = job->color_range;
     context->chroma_sample_location = job->chroma_location;
 
     if (!job->inline_parameter_sets)
@@ -878,7 +938,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
         }
     }
 
-    if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265)
+    if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT)
     {
         // Set profile and level
         context->profile = FF_PROFILE_UNKNOWN;
@@ -903,7 +963,8 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
     }
 
     if (job->vcodec == HB_VCODEC_FFMPEG_NVENC_H264 ||
-        job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265)
+        job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265 ||
+        job->vcodec == HB_VCODEC_FFMPEG_NVENC_H265_10BIT)
     {
         // Force IDR frames when we force a new keyframe for chapters
         av_dict_set( &av_opts, "forced-idr", "1", 0 );
@@ -932,7 +993,7 @@ int encavcodecInit( hb_work_object_t * w, hb_job_t * job )
     }
 
     // Make VCE h.265 encoder emit an IDR for every GOP
-    if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265)
+    if (job->vcodec == HB_VCODEC_FFMPEG_VCE_H265 || job->vcodec == HB_VCODEC_FFMPEG_VCE_H265_10BIT)
     {
         av_dict_set(&av_opts, "gops_per_idr", "1", 0);
     }
@@ -1299,7 +1360,20 @@ static void Encode( hb_work_object_t *w, hb_buffer_t *in,
     frame.pts = pv->frameno_in++;
 
     // Encode
+#if HB_PROJECT_FEATURE_NVENC
+    if (in->hw_ctx.frame)
+    {
+        AVFrame *p_frame = in->hw_ctx.frame;
+        av_frame_copy_props(p_frame, &frame);
+        ret = avcodec_send_frame(pv->context, p_frame);
+    }
+    else
+    {
+        ret = avcodec_send_frame(pv->context, &frame);
+    }
+#else
     ret = avcodec_send_frame(pv->context, &frame);
+#endif
     if (ret < 0)
     {
         hb_log("encavcodec: avcodec_send_frame failed");
@@ -1366,6 +1440,147 @@ int encavcodecWork( hb_work_object_t * w, hb_buffer_t ** buf_in,
     return HB_WORK_OK;
 }
 
+/**
+ * Encoder options and presets
+ */
+
+static int apply_svt_av1_options(hb_job_t *job, AVCodecContext *context, AVDictionary **av_opts, hb_dict_t *opts)
+{
+    context->profile = FF_PROFILE_UNKNOWN;
+    if (job->encoder_profile != NULL && *job->encoder_profile)
+    {
+        if (!strcasecmp(job->encoder_profile, "main"))
+            context->profile = FF_PROFILE_AV1_MAIN;
+        else if (!strcasecmp(job->encoder_profile, "high"))
+             context->profile = FF_PROFILE_AV1_HIGH;
+        else if (!strcasecmp(job->encoder_profile, "professional"))
+            context->profile = FF_PROFILE_AV1_PROFESSIONAL;
+    }
+    context->level = FF_LEVEL_UNKNOWN;
+    if (job->encoder_level != NULL && *job->encoder_level)
+    {
+        int i = 1;
+        while (hb_av1_level_names[i] != NULL)
+        {
+            if (!strcasecmp(job->encoder_level, hb_av1_level_names[i]))
+                context->level = hb_av1_level_values[i];
+            ++i;
+        }
+    }
+
+    if (job->encoder_tune != NULL && !strstr("psnr", job->encoder_tune))
+    {
+        hb_dict_set_int(opts, "tune", 1);
+    }
+    else
+    {
+        hb_dict_set_int(opts, "tune", 0);
+    }
+
+    if (job->encoder_tune != NULL && !strstr("fastdecode", job->encoder_tune))
+    {
+        hb_dict_set_int(opts, "fast-decode", 1);
+    }
+    else
+    {
+        hb_dict_set_int(opts, "fast-decode", 0);
+    }
+
+    if (job->color_transfer == HB_COLR_TRA_SMPTEST2084)
+    {
+        // Mastering display metadata.
+        if (job->mastering.has_primaries && job->mastering.has_luminance)
+        {
+            char mastering_display_color_volume[256];
+            snprintf(mastering_display_color_volume, sizeof(mastering_display_color_volume),
+                     "G(%5.4f,%5.4f)B(%5.4f,%5.4f)R(%5.4f,%5.4f)WP(%5.4f,%5.4f)L(%5.4f,%5.4f)",
+                     hb_q2d(job->mastering.display_primaries[1][0]),
+                     hb_q2d(job->mastering.display_primaries[1][1]),
+                     hb_q2d(job->mastering.display_primaries[2][0]),
+                     hb_q2d(job->mastering.display_primaries[2][1]),
+                     hb_q2d(job->mastering.display_primaries[0][0]),
+                     hb_q2d(job->mastering.display_primaries[0][1]),
+                     hb_q2d(job->mastering.white_point[0]),
+                     hb_q2d(job->mastering.white_point[1]),
+                     hb_q2d(job->mastering.max_luminance),
+                     hb_q2d(job->mastering.min_luminance));
+
+            hb_dict_set_string(opts, "mastering-display", mastering_display_color_volume);
+        }
+
+        // Content light level.
+        if (job->coll.max_cll && job->coll.max_fall)
+        {
+            char content_light_level[256];
+            snprintf(content_light_level, sizeof(content_light_level),
+                     "%u,%u", job->coll.max_cll, job->coll.max_fall);
+
+            hb_dict_set_string(opts, "content-light", content_light_level);
+        }
+    }
+
+    if (hb_dict_get(opts, "compressed-ten-bit-format"))
+    {
+        hb_log("apply_svt_av1_options [warning]: compressed-ten-bit-format is not supported, disabling");
+        hb_dict_remove(opts, "compressed-ten-bit-format");
+    }
+
+    char *param_str = hb_value_get_string_xform(opts);
+    av_dict_set(av_opts, "svtav1-params", param_str, 0);
+    free(param_str);
+
+    return 0;
+}
+
+static int apply_options(hb_job_t *job, AVCodecContext *context, AVDictionary **av_opts, hb_dict_t *lavc_opts)
+{
+    /* iterate through lavc_opts and have avutil parse the options for us */
+    hb_dict_iter_t iter;
+    for (iter  = hb_dict_iter_init(lavc_opts);
+         iter != HB_DICT_ITER_DONE;
+         iter  = hb_dict_iter_next(lavc_opts, iter))
+    {
+        const char *key = hb_dict_iter_key(iter);
+        hb_value_t *value = hb_dict_iter_value(iter);
+        char *str = hb_value_get_string_xform(value);
+
+        /* Here's where the strings are passed to avutil for parsing. */
+        av_dict_set(av_opts, key, str, 0);
+        free(str);
+    }
+
+    return 0;
+}
+
+static int apply_encoder_options(hb_job_t *job, AVCodecContext *context, AVDictionary **av_opts)
+{
+    /* place job->encoder_options in an hb_dict_t for convenience */
+    hb_dict_t *lavc_opts = NULL;
+    if (job->encoder_options != NULL && *job->encoder_options)
+    {
+        lavc_opts = hb_encopts_to_dict(job->encoder_options, job->vcodec);
+    }
+    else
+    {
+        lavc_opts = hb_dict_init();
+    }
+
+    switch (job->vcodec) {
+        case HB_VCODEC_FFMPEG_SVT_AV1:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            apply_svt_av1_options(job, context, av_opts, lavc_opts);
+            break;
+
+        default:
+            apply_options(job, context, av_opts, lavc_opts);
+            break;
+    }
+
+    hb_dict_free(&lavc_opts);
+
+    return 0;
+}
+
 static int apply_vpx_preset(AVDictionary ** av_opts, const char * preset)
 {
     if (preset == NULL)
@@ -1431,6 +1646,27 @@ static int apply_vp9_preset(AVDictionary ** av_opts, const char * preset)
     return apply_vpx_preset(av_opts, preset);
 }
 
+static int apply_vp9_10bit_preset(AVDictionary ** av_opts, const char * preset)
+{
+    av_dict_set(av_opts, "row-mt", "1", 0);
+    av_dict_set(av_opts, "profile", "2", 0);
+    return apply_vpx_preset(av_opts, preset);
+}
+
+static int apply_av1_preset(AVDictionary ** av_opts, const char * preset)
+{
+    if (preset == NULL)
+    {
+        av_dict_set( av_opts, "preset", "5", 0);
+    }
+    else
+    {
+        av_dict_set( av_opts, "preset", preset, 0);
+    }
+
+    return 0;
+}
+
 static int apply_encoder_preset(int vcodec, AVDictionary ** av_opts,
                                 const char * preset)
 {
@@ -1440,10 +1676,16 @@ static int apply_encoder_preset(int vcodec, AVDictionary ** av_opts,
             return apply_vp8_preset(av_opts, preset);
         case HB_VCODEC_FFMPEG_VP9:
             return apply_vp9_preset(av_opts, preset);
-            
+        case HB_VCODEC_FFMPEG_VP9_10BIT:
+            return apply_vp9_10bit_preset(av_opts, preset);
+        case HB_VCODEC_FFMPEG_SVT_AV1:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            return apply_av1_preset(av_opts, preset);
+
 #if HB_PROJECT_FEATURE_NVENC
         case HB_VCODEC_FFMPEG_NVENC_H264:
         case HB_VCODEC_FFMPEG_NVENC_H265:
+        case HB_VCODEC_FFMPEG_NVENC_H265_10BIT:
             preset = hb_map_nvenc_preset_name(preset);
             av_dict_set( av_opts, "preset", preset, 0);
             break;
@@ -1461,20 +1703,40 @@ const char* const* hb_av_preset_get_names(int encoder)
     {
         case HB_VCODEC_FFMPEG_VP8:
         case HB_VCODEC_FFMPEG_VP9:
+        case HB_VCODEC_FFMPEG_VP9_10BIT:
             return vpx_preset_names;
 
         case HB_VCODEC_FFMPEG_VCE_H264:
         case HB_VCODEC_FFMPEG_VCE_H265:
+        case HB_VCODEC_FFMPEG_VCE_H265_10BIT:
             return hb_vce_preset_names;
 
         case HB_VCODEC_FFMPEG_NVENC_H264:
         case HB_VCODEC_FFMPEG_NVENC_H265:
+        case HB_VCODEC_FFMPEG_NVENC_H265_10BIT:
             return h26x_nvenc_preset_names;
 
         case HB_VCODEC_FFMPEG_MF_H264:
         case HB_VCODEC_FFMPEG_MF_H265:
             return h26x_mf_preset_name;
 
+        case HB_VCODEC_FFMPEG_SVT_AV1:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            return av1_svt_preset_names;
+
+        default:
+            return NULL;
+    }
+}
+
+const char* const* hb_av_tune_get_names(int encoder)
+{
+    switch (encoder)
+    {
+        case HB_VCODEC_FFMPEG_SVT_AV1:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            return av1_svt_tune_names;
+
         default:
             return NULL;
     }
@@ -1488,10 +1750,15 @@ const char* const* hb_av_profile_get_names(int encoder)
             return h264_nvenc_profile_names;
         case HB_VCODEC_FFMPEG_NVENC_H265:
             return h265_nvenc_profile_names;
+        case HB_VCODEC_FFMPEG_NVENC_H265_10BIT:
+            return h265_nvenc_10bit_profile_names;
         case HB_VCODEC_FFMPEG_MF_H264:
             return h264_mf_profile_name;
         case HB_VCODEC_FFMPEG_MF_H265:
             return h265_mf_profile_name;
+        case HB_VCODEC_FFMPEG_SVT_AV1:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            return av1_svt_profile_names;
 
          default:
              return NULL;
@@ -1506,7 +1773,21 @@ const int* hb_av_get_pix_fmts(int encoder)
         case HB_VCODEC_FFMPEG_MF_H265:
             return h26x_mf_pix_fmts;
 
+        case HB_VCODEC_FFMPEG_NVENC_H264:
+        case HB_VCODEC_FFMPEG_NVENC_H265:
+            return nvenc_pix_formats;
+
+        case HB_VCODEC_FFMPEG_NVENC_H265_10BIT:
+            return nvenc_pix_formats_10bit;
+
+        case HB_VCODEC_FFMPEG_VCE_H265_10BIT:
+            return vce_pix_formats_10bit;
+
+        case HB_VCODEC_FFMPEG_VP9_10BIT:
+        case HB_VCODEC_FFMPEG_SVT_AV1_10BIT:
+            return standard_10bit_pix_fmts;
+
          default:
-             return pix_fmts;
+             return standard_pix_fmts;
      }
 }
