@@ -11,6 +11,7 @@
 
 #if HB_PROJECT_FEATURE_X265
 
+#include "libavutil/avutil.h"
 #include "handbrake/handbrake.h"
 #include "handbrake/hb_dict.h"
 #include "handbrake/h265_common.h"
@@ -211,7 +212,7 @@ int encx265Init(hb_work_object_t *w, hb_job_t *job)
     {
         if (depth > 8)
         {
-            if (param_parse(pv, param, "hdr-opt", "1"))
+            if (param_parse(pv, param, "hdr10-opt", "1"))
             {
                 goto fail;
             }
@@ -375,6 +376,21 @@ int encx265Init(hb_work_object_t *w, hb_job_t *job)
     param->sourceWidth    = job->width;
     param->sourceHeight   = job->height;
 
+    switch (job->output_pix_fmt)
+    {
+        case AV_PIX_FMT_YUV422P:
+        case AV_PIX_FMT_YUV422P10:
+        case AV_PIX_FMT_YUV422P12:
+        case AV_PIX_FMT_YUV422P16:
+            param->internalCsp = X265_CSP_I422;
+            break;
+        case AV_PIX_FMT_YUV444P:
+        case AV_PIX_FMT_YUV444P10:
+        case AV_PIX_FMT_YUV444P12:
+        case AV_PIX_FMT_YUV444P16:
+            param->internalCsp = X265_CSP_I444;
+    }
+
     /*
      * Let x265 determine whether to use an aspect ratio
      * index vs. the extended SAR index + SAR width/height.
