@@ -76,6 +76,8 @@ enum hb_cpu_platform
     HB_CPU_PLATFORM_INTEL_CML,
     HB_CPU_PLATFORM_INTEL_ICL,
     HB_CPU_PLATFORM_INTEL_TGL,
+    HB_CPU_PLATFORM_INTEL_ADL,
+    HB_CPU_PLATFORM_INTEL_DG2,
 };
 int         hb_get_cpu_count(void);
 int         hb_get_cpu_platform(void);
