@@ -59,7 +59,7 @@ typedef struct{
 #if !HB_QSV_ONEVPL
 int qsv_nv12_to_yuv420(struct SwsContext* sws_context,hb_buffer_t* dst, mfxFrameSurface1* src,mfxCoreInterface *core);
 #endif
-int qsv_yuv420_to_nv12(struct SwsContext* sws_context,mfxFrameSurface1* dst, hb_buffer_t* src);
-
+int qsv_convert_yuv_to_nv12(struct SwsContext *sws_context, mfxFrameSurface1 *dst, hb_buffer_t *src);
+int qsv_copy_buffer_to_surface(mfxFrameSurface1 *dst, hb_buffer_t *src);
 #endif // HB_PROJECT_FEATURE_QSV
 #endif // HANDBRAKE_QSV_MEMORY_H
