@@ -235,6 +235,8 @@ static hb_dict_t* hb_title_to_dict_internal( hb_title_t *title )
         "s:{s:o, s:o, s:{s:o, s:o}},"
         // Crop[Top, Bottom, Left, Right]}
         "s:[oooo],"
+        // LooseCrop[Top, Bottom, Left, Right]}
+        "s:[oooo],"
         // Color {Format, Range, Primary, Transfer, Matrix, ChromaLocation}
         "s:{s:o, s:o, s:o, s:o, s:o, s:o},"
         // FrameRate {Num, Den}
@@ -265,6 +267,10 @@ static hb_dict_t* hb_title_to_dict_internal( hb_title_t *title )
                             hb_value_int(title->crop[1]),
                             hb_value_int(title->crop[2]),
                             hb_value_int(title->crop[3]),
+    "LooseCrop",            hb_value_int(title->loose_crop[0]),
+                            hb_value_int(title->loose_crop[1]),
+                            hb_value_int(title->loose_crop[2]),
+                            hb_value_int(title->loose_crop[3]),
     "Color",
         "Format",           hb_value_int(title->pix_fmt),
         "Range",            hb_value_int(title->color_range),
@@ -505,8 +511,8 @@ hb_dict_t* hb_job_to_dict( const hb_job_t * job )
     "s:{s:o, s:o, s:o,},"
     // PAR {Num, Den}
     "s:{s:o, s:o},"
-    // Video {Encoder, QSV {Decode, AsyncDepth, AdapterIndex}}
-    "s:{s:o, s:{s:o, s:o, s:o}},"
+    // Video {Encoder, HardwareDecode, QSV {Decode, AsyncDepth, AdapterIndex}}
+    "s:{s:o, s:o, s:{s:o, s:o, s:o}},"
     // Audio {CopyMask, FallbackEncoder, AudioList []}
     "s:{s:[], s:o, s:[]},"
     // Subtitles {Search {Enable, Forced, Default, Burn}, SubtitleList []}
@@ -532,6 +538,7 @@ hb_dict_t* hb_job_to_dict( const hb_job_t * job )
             "Den",              hb_value_int(job->par.den),
         "Video",
             "Encoder",          hb_value_int(job->vcodec),
+            "HardwareDecode",   hb_value_int(job->hw_decode),
             "QSV",
                 "Decode",       hb_value_bool(job->qsv.decode),
                 "AsyncDepth",   hb_value_int(job->qsv.async_depth),
@@ -1022,6 +1029,7 @@ hb_job_t* hb_dict_to_job( hb_handle_t * h, hb_dict_t *dict )
     //       Mastering,
     //       ContentLightLevel,
     //       ColorPrimariesOverride, ColorTransferOverride, ColorMatrixOverride,
+    //       HardwareDecode
     //       QSV {Decode, AsyncDepth, AdapterIndex}}
     "s:{s:o, s?F, s?i, s?s, s?s, s?s, s?s, s?s,"
     "   s?b, s?b,"
@@ -1030,6 +1038,7 @@ hb_job_t* hb_dict_to_job( hb_handle_t * h, hb_dict_t *dict )
     "   s?o,"
     "   s?o,"
     "   s?i, s?i, s?i,"
+    "   s?i,"
     "   s?{s?b, s?i, s?i}},"
     // Audio {CopyMask, FallbackEncoder, AudioList}
     "s?{s?o, s?o, s?o},"
@@ -1084,6 +1093,7 @@ hb_job_t* hb_dict_to_job( hb_handle_t * h, hb_dict_t *dict )
             "ColorPrimariesOverride", unpack_i(&job->color_prim_override),
             "ColorTransferOverride",  unpack_i(&job->color_transfer_override),
             "ColorMatrixOverride",    unpack_i(&job->color_matrix_override),
+            "HardwareDecode",         unpack_i(&job->hw_decode),
             "QSV",
                 "Decode",           unpack_b(&job->qsv.decode),
                 "AsyncDepth",       unpack_i(&job->qsv.async_depth),
