@@ -1,6 +1,6 @@
 /* param.c
  *
- * Copyright (c) 2003-2019 HandBrake Team
+ * Copyright (c) 2003-2022 HandBrake Team
  * This file is part of the HandBrake source code
  * Homepage: <http://handbrake.fr/>.
  * It may be used under the terms of the GNU General Public License v2.
@@ -94,6 +94,7 @@ static hb_filter_param_t hqdn3d_presets[] =
 
 static hb_filter_param_t chroma_smooth_presets[] =
 {
+    { 0, "Off",         "off",        NULL              },
     { 1, "Custom",      "custom",     NULL              },
     { 2, "Ultralight",  "ultralight", NULL              },
     { 3, "Light",       "light",      NULL              },
@@ -115,6 +116,17 @@ static hb_filter_param_t chroma_smooth_tunes[] =
     { 0, NULL,          NULL,         NULL              }
 };
 
+static hb_filter_param_t colorspace_presets[] =
+{
+    { 0, "Off",             "off",          NULL        },
+    { 1, "Custom",          "custom",       NULL        },
+    { 2, "BT.2020",         "bt2020",       "primaries=bt2020:transfer=bt2020-10:matrix=bt2020ncl:tonemap=hable:desat=0" },
+    { 3, "BT.709",          "bt709",        "primaries=bt709:transfer=bt709:matrix=bt709:tonemap=hable:desat=0"          },
+    { 4, "BT.601 SMPTE-C",  "bt601-6-525",  "primaries=smpte170m:transfer=bt709:matrix=smpte170m:tonemap=hable:desat=0"  },
+    { 5, "BT.601 EBU",      "bt601-6-625",  "primaries=bt470bg:transfer=bt709:matrix=smpte170m:tonemap=hable:desat=0"    },
+    { 0, NULL,              NULL,           NULL        }
+};
+
 static hb_filter_param_t unsharp_presets[] =
 {
     { 1, "Custom",      "custom",     NULL              },
@@ -199,7 +211,7 @@ static hb_filter_param_t decomb_presets[] =
     { 0, NULL,          NULL,         NULL              }
 };
 
-static hb_filter_param_t deinterlace_presets[] =
+static hb_filter_param_t yadif_presets[] =
 {
     { 1, "Custom",             "custom",       NULL             },
     { 3, "Default",            "default",      "mode=3"         },
@@ -215,6 +227,14 @@ static hb_filter_param_t deinterlace_presets[] =
     { 7, "QSV",                "qsv",          "mode=3"         }
 };
 
+static hb_filter_param_t bwdif_presets[] =
+{
+    { 1, "Custom",             "custom",       NULL             },
+    { 3, "Default",            "default",      "mode=3"         },
+    { 2, "Bob",                "bob",          "mode=7"         },
+    { 0,  NULL,                NULL,           NULL             },
+};
+
 typedef struct
 {
     int                filter_id;
@@ -237,6 +257,9 @@ static filter_param_map_t param_map[] =
       sizeof(chroma_smooth_presets) / sizeof(hb_filter_param_t),
       sizeof(chroma_smooth_tunes)   / sizeof(hb_filter_param_t),  },
 
+    { HB_FILTER_COLORSPACE, colorspace_presets, NULL,
+      sizeof(colorspace_presets) / sizeof(hb_filter_param_t),  0, },
+
     { HB_FILTER_UNSHARP,     unsharp_presets,     unsharp_tunes,
       sizeof(unsharp_presets) / sizeof(hb_filter_param_t),
       sizeof(unsharp_tunes)   / sizeof(hb_filter_param_t),        },
@@ -254,8 +277,11 @@ static filter_param_map_t param_map[] =
     { HB_FILTER_DECOMB,      decomb_presets,      NULL,
       sizeof(decomb_presets) / sizeof(hb_filter_param_t),      0, },
 
-    { HB_FILTER_DEINTERLACE, deinterlace_presets, NULL,
-      sizeof(deinterlace_presets) / sizeof(hb_filter_param_t), 0, },
+    { HB_FILTER_YADIF, yadif_presets, NULL,
+      sizeof(yadif_presets) / sizeof(hb_filter_param_t),       0, },
+
+    { HB_FILTER_BWDIF, bwdif_presets, NULL,
+      sizeof(bwdif_presets) / sizeof(hb_filter_param_t),       0, },
 
     { HB_FILTER_DEBLOCK, deblock_presets, deblock_tunes,
       sizeof(deblock_presets) / sizeof(hb_filter_param_t),
@@ -269,7 +295,7 @@ void hb_param_configure_qsv(void)
 #if HB_PROJECT_FEATURE_QSV
     if (!hb_qsv_available())
     {
-        memset(&deinterlace_presets[4], 0, sizeof(hb_filter_param_t));
+        memset(&yadif_presets[4], 0, sizeof(hb_filter_param_t));
     }
 #endif
 }
@@ -1258,7 +1284,9 @@ hb_generate_filter_settings(int filter_id, const char *preset, const char *tune,
         case HB_FILTER_DECOMB:
         case HB_FILTER_DETELECINE:
         case HB_FILTER_HQDN3D:
-        case HB_FILTER_DEINTERLACE:
+        case HB_FILTER_YADIF:
+        case HB_FILTER_BWDIF:
+        case HB_FILTER_COLORSPACE:
             settings = generate_generic_settings(filter_id, preset,
                                                  tune, custom);
             break;
@@ -1400,6 +1428,10 @@ char * hb_filter_get_presets_json(int filter_id)
     hb_filter_param_t * table;
 
     table = filter_param_get_presets_internal(filter_id, NULL);
+    
+    if (table == NULL){
+        return NULL;
+    }
 
     for (count = 0; table[count].name != NULL; count++);
     for (ii = 0; ii < count; ii++)
@@ -1423,6 +1455,10 @@ char * hb_filter_get_tunes_json(int filter_id)
     hb_filter_param_t * table;
 
     table = filter_param_get_tunes_internal(filter_id, NULL);
+    
+    if (table == NULL){
+        return NULL;
+    }
 
     for (count = 0; table[count].name != NULL; count++);
     for (ii = 0; ii < count; ii++)
