@@ -7,11 +7,12 @@
    For full terms see the file COPYING file or visit http://www.gnu.org/licenses/gpl-2.0.html
  */
 
-#include "handbrake/handbrake.h"
-
 #include <VideoToolbox/VideoToolbox.h>
 #include <CoreMedia/CoreMedia.h>
 #include <CoreVideo/CoreVideo.h>
+#include "libavutil/avutil.h"
+
+#include "handbrake/handbrake.h"
 
 int  encvt_init(hb_work_object_t *, hb_job_t *);
 int  encvt_work(hb_work_object_t *, hb_buffer_t **, hb_buffer_t **);
@@ -26,9 +27,7 @@ hb_work_object_t hb_encvt =
     encvt_close
 };
 
-#define FRAME_INFO_MAX2 (8)  // 2^8  = 256;  90000/256    = 352 frames/sec
-#define FRAME_INFO_MIN2 (17) // 2^17 = 128K; 90000/131072 = 1.4 frames/sec
-#define FRAME_INFO_SIZE (1 << (FRAME_INFO_MIN2 - FRAME_INFO_MAX2 + 1))
+#define FRAME_INFO_SIZE 512
 #define FRAME_INFO_MASK (FRAME_INFO_SIZE - 1)
 
 struct hb_work_private_s
@@ -173,6 +172,7 @@ enum
 {
     HB_VT_H265_PROFILE_MAIN = 0,
     HB_VT_H265_PROFILE_MAIN_10,
+    HB_VT_H265_PROFILE_MAIN_422_10,
     HB_VT_H265_PROFILE_NB,
 };
 
@@ -183,13 +183,9 @@ static struct
 }
 hb_vt_h265_levels[] =
 {
-    { "auto", { CFSTR("HEVC_Main_AutoLevel"), CFSTR("HEVC_Main10_AutoLevel") }, }
+    { "auto", { CFSTR("HEVC_Main_AutoLevel"), CFSTR("HEVC_Main10_AutoLevel"), CFSTR("HEVC_Main42210_AutoLevel") } }
 };
 
-/*
- * see comments in definition of 'frame_info' in pv struct for description
- * of what these routines are doing.
- */
 static void save_frame_info(hb_work_private_t *pv, hb_buffer_t *in)
 {
     int i = pv->frameno_in & FRAME_INFO_MASK;
@@ -243,6 +239,8 @@ static CFStringRef hb_vt_colr_tra_xlat(int color_transfer)
             return kCVImageBufferTransferFunction_SMPTE_ST_2084_PQ;
         case HB_COLR_TRA_LINEAR:
             if (__builtin_available(macOS 10.14, *)) { return kCVImageBufferTransferFunction_Linear; }
+        case HB_COLR_TRA_IEC61966_2_1:
+            return kCVImageBufferTransferFunction_sRGB;
         case HB_COLR_TRA_ARIB_STD_B67:
             return kCVImageBufferTransferFunction_ITU_R_2100_HLG;
         case HB_COLR_TRA_GAMMA22:
@@ -405,7 +403,7 @@ static OSType hb_vt_get_cv_pixel_format(hb_job_t* job)
     }
     else if (job->output_pix_fmt == AV_PIX_FMT_YUV420P)
     {
-        return job->output_pix_fmt == AVCOL_RANGE_JPEG ?
+        return job->color_range == AVCOL_RANGE_JPEG ?
                                         kCVPixelFormatType_420YpCbCr8PlanarFullRange :
                                         kCVPixelFormatType_420YpCbCr8Planar;
     }
@@ -415,10 +413,38 @@ static OSType hb_vt_get_cv_pixel_format(hb_job_t* job)
     }
     else if (job->output_pix_fmt == AV_PIX_FMT_P010LE)
     {
-        return job->output_pix_fmt == AVCOL_RANGE_JPEG ?
+        return job->color_range == AVCOL_RANGE_JPEG ?
                                         kCVPixelFormatType_420YpCbCr10BiPlanarFullRange :
                                         kCVPixelFormatType_420YpCbCr10BiPlanarVideoRange;
     }
+    else if (job->output_pix_fmt == AV_PIX_FMT_NV16)
+    {
+        return job->color_range == AVCOL_RANGE_JPEG ?
+                                        kCVPixelFormatType_422YpCbCr8BiPlanarFullRange :
+                                        kCVPixelFormatType_422YpCbCr8BiPlanarVideoRange;
+    }
+    else if (job->output_pix_fmt == AV_PIX_FMT_P210)
+    {
+        return job->color_range == AVCOL_RANGE_JPEG ?
+                                        kCVPixelFormatType_422YpCbCr10BiPlanarFullRange :
+                                        kCVPixelFormatType_422YpCbCr10BiPlanarVideoRange;
+    }
+    else if (job->output_pix_fmt == AV_PIX_FMT_NV24)
+    {
+        return job->color_range == AVCOL_RANGE_JPEG ?
+                                        kCVPixelFormatType_444YpCbCr8BiPlanarFullRange :
+                                        kCVPixelFormatType_444YpCbCr8BiPlanarVideoRange;
+    }
+    else if (job->output_pix_fmt == AV_PIX_FMT_P410)
+    {
+        return job->color_range == AVCOL_RANGE_JPEG ?
+                                        kCVPixelFormatType_444YpCbCr10BiPlanarFullRange :
+                                        kCVPixelFormatType_444YpCbCr10BiPlanarVideoRange;
+    }
+    else if (job->output_pix_fmt == AV_PIX_FMT_P416)
+    {
+        return kCVPixelFormatType_444YpCbCr16BiPlanarVideoRange;
+    }
     else
     {
         return 0;
@@ -482,11 +508,15 @@ static int hb_vt_settings_xlat(hb_work_private_t *pv, hb_job_t *job)
         }
         else if (job->vcodec == HB_VCODEC_VT_H265_10BIT)
         {
-            if (!strcasecmp(job->encoder_profile, "main") ||
+            if (!strcasecmp(job->encoder_profile, "main10") ||
                 !strcasecmp(job->encoder_profile, "auto"))
             {
                 pv->settings.profile = HB_VT_H265_PROFILE_MAIN_10;
             }
+            else if (!strcasecmp(job->encoder_profile, "main422-10"))
+            {
+                pv->settings.profile = HB_VT_H265_PROFILE_MAIN_422_10;
+            }
             else
             {
                 hb_error("encvt_Init: invalid profile '%s'", job->encoder_profile);
@@ -1652,6 +1682,7 @@ static hb_buffer_t *vt_encode(hb_work_object_t *w, hb_buffer_t *in)
 
     if (kCVReturnSuccess != err)
     {
+        hb_buffer_close(&in);
         hb_log("VTCompressionSession: CVPixelBuffer error");
     }
     else
